share/hedgewars/Data/Scripts/Multiplayer/Racer.lua
changeset 10847 b68e35d6e376
parent 10292 1c6639b49afc
child 10856 d080b8d4c114
--- a/share/hedgewars/Data/Scripts/Multiplayer/Racer.lua	Sun Mar 01 21:06:27 2015 +0100
+++ b/share/hedgewars/Data/Scripts/Multiplayer/Racer.lua	Tue Mar 03 22:22:29 2015 +0300
@@ -742,13 +742,14 @@
     usedPortal = usedWeapons[amPortalGun] ~= nil
     usedSaucer = usedWeapons[amJetpack] ~= nil
     
+    usedWeapons[amNothing] = nil
     usedWeapons[amRope] = nil
     usedWeapons[amPortalGun] = nil
     usedWeapons[amJetpack] = nil
 
     usedOther = next(usedWeapons) ~= nil
 
-    if usedOther then -- smth besides skip, rope, portal or saucer used
+    if usedOther then -- smth besides nothing, skip, rope, portal or saucer used
         raceType = "unknown race"
     elseif usedRope and not usedPortal and not usedSaucer then
         raceType = "rope race"